==> 0.8.0.tar.gz: test/model/value_transform_test.dart <==
@TestGroup(description: 'ValueTransform')
library fields.test.model.value_transform;

import 'package:bench/bench.dart';
import 'package:unittest/unittest.dart';
import 'package:fields/model.dart';

main() => reflectTests();

// -----------------------------------------------------------------------------
// Setup
// -----------------------------------------------------------------------------

@Setup
void setup() {}

@Teardown
void teardown() {
  valueTransforms.remove(const ValueTransform<String, int>(_string2int));
  valueTransforms.remove(const ValueTransform<Rectangle, RectangleF>(_r2rf));
}

int _string2int(int value) => throw new UnimplementedError();

class Rectangle {
  int x, y, w, h;
}

class RectangleF {
  double x, y, w, h;
}

RectangleF _r2rf(Rectangle value) => new RectangleF()
    ..x = value.x.toDouble()
    ..y = value.y.toDouble()
    ..w = value.w.toDouble()
    ..h = value.h.toDouble();

// -----------------------------------------------------------------------------
// Basic
// -----------------------------------------------------------------------------

@Test('Test that simple types can be transformed.')
void testCanTransformSimpleTypes() {
  expect(ValueTransform.canTransform(int, int), isTrue);
  expect(ValueTransform.canTransform(String, int), isTrue);
  expect(ValueTransform.canTransform(double, num), isTrue);
  expect(ValueTransform.canTransform(int, num), isTrue);
  expect(ValueTransform.canTransform(num, int), isTrue);
  expect(ValueTransform.canTransform(num, double), isTrue);
}

@Test('Test a valid string to int transform.')
void testTransformStringToInt() {
  final String s = '42';
  final int i = ValueTransform.transform(s, String, int);
  expect(i, equals(42));
}

@Test('Test an erroneous string to int transform.')
@ExpectError(const isInstanceOf<ValueTransformError>())
void testTransformStringToIntThrows() {
  final String s = '42.123';
  ValueTransform.transform(s, String, int);
}

@Test('Test that a string to int transform where value is! a string throws.')
@ExpectError(const isInstanceOf<TypeError>())
void testTransformStringToIntValueIsNotStringThrows() {
  final map = { 'foo' : 'bar' };
  ValueTransform.transform(map, String, int); 
}

@Test()
void testTransformNotHasInverse() {
  var xform = new ValueTransform<int, bool>((_) {});
  expect(xform, isNotNull);
  expect(xform.hasInverse, isFalse);
}

@Test()
void testTransformHasInverse() {
  var xform = new ValueTransform<int, bool>((_) {}, (_) {});
  expect(xform, isNotNull);
  expect(xform.hasInverse, isTrue);
}

@Test()
void testTransformInverse() {
  final letters = const [ 'a', 'b', 'c'];
  var xform = new ValueTransform<int, String>(
      (i) => letters[i], 
      (s) => letters.indexOf(s));  
  expect(xform.hasInverse, isTrue);
  expect(xform(2), equals('c'));
  expect(xform.inverse('b'), equals(1));
  expect(xform.inverse(xform(0)), equals(0));
}

@Test()
@ExpectError(isUnsupportedError)
void testTransformNoInverseThrows() {
  var xform = new ValueTransform<int, bool>((i) => i >= 1);
  xform.inverse(false);
}

// -----------------------------------------------------------------------------
// Custom
// -----------------------------------------------------------------------------

@Test('Test the registration of a custom string to int transform.')
void testRegisterCustomTransformStringToInt() {
  valueTransforms.add(const ValueTransform<String, int>(_string2int));
  expect(ValueTransform.canTransform(String, int), isTrue);
}

@Test('Test the registration of a custom rectangle transform.')
void testRegisterRectangleTransform() {
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isFalse);
  final transform = const ValueTransform<Rectangle, RectangleF>(_r2rf);
  valueTransforms.add(transform);
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isTrue);
  expect(valueTransforms.remove(transform), isTrue);
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isFalse);
}

@Test('Test a valid rectangle transform.')
void testTransformRectangle() {  
  final transform = const ValueTransform<Rectangle, RectangleF>(_r2rf);
  valueTransforms.add(transform);  
  final r = new Rectangle()..x = 1..y = 2..w = 3..h = 4;
  final rf = ValueTransform.transform(r, Rectangle, RectangleF);
  expect(rf, const isInstanceOf<RectangleF>());
  expect(rf.x, equals(1));
  expect(rf.y, equals(2));
  expect(rf.w, equals(3));
  expect(rf.h, equals(4));
  expect(valueTransforms.remove(transform), isTrue);
}

==> 0.8.4.tar.gz: test/model/value_transform_test.dart <==
@TestGroup('ValueTransform')
library fields.test.model.value_transform;

import 'package:bench/bench.dart';
import 'package:unittest/unittest.dart';
import 'package:fields/model.dart';

main() => reflectTests();

// -----------------------------------------------------------------------------
// Setup
// -----------------------------------------------------------------------------

@Setup
void setup() {}

@Teardown
void teardown() {
  valueTransforms.remove(const ValueTransform<String, int>(_string2int));
  valueTransforms.remove(const ValueTransform<Rectangle, RectangleF>(_r2rf));
}

int _string2int(int value) => throw new UnimplementedError();

class Rectangle {
  int x, y, w, h;
}

class RectangleF {
  double x, y, w, h;
}

RectangleF _r2rf(Rectangle value) => new RectangleF()
    ..x = value.x.toDouble()
    ..y = value.y.toDouble()
    ..w = value.w.toDouble()
    ..h = value.h.toDouble();

// -----------------------------------------------------------------------------
// Basic
// -----------------------------------------------------------------------------

@Test('Test that simple types can be transformed.')
void testCanTransformSimpleTypes() {
  expect(ValueTransform.canTransform(int, int), isTrue);
  expect(ValueTransform.canTransform(String, int), isTrue);
  expect(ValueTransform.canTransform(double, num), isTrue);
  expect(ValueTransform.canTransform(int, num), isTrue);
  expect(ValueTransform.canTransform(num, int), isTrue);
  expect(ValueTransform.canTransform(num, double), isTrue);
}

@Test('Test a valid string to int transform.')
void testTransformStringToInt() {
  final String s = '42';
  final int i = ValueTransform.transform(s, String, int);
  expect(i, equals(42));
}

@Test('Test an erroneous string to int transform.')
@ExpectError(isFormatException)
void testTransformStringToIntThrows() {
  final String s = '42.123';
  ValueTransform.transform(s, String, int);
}

@Test('Test that a string to int transform where value is! a string throws.')
@ExpectError(const isInstanceOf<TypeError>())
void testTransformStringToIntValueIsNotStringThrows() {
  final map = { 'foo' : 'bar' };
  ValueTransform.transform(map, String, int); 
}

@Test()
void testTransformNotHasInverse() {
  var xform = new ValueTransform<int, bool>((_) {});
  expect(xform, isNotNull);
  expect(xform.hasInverse, isFalse);
}

@Test()
void testTransformHasInverse() {
  var xform = new ValueTransform<int, bool>((_) {}, (_) {});
  expect(xform, isNotNull);
  expect(xform.hasInverse, isTrue);
}

@Test()
void testTransformInverse() {
  final letters = const [ 'a', 'b', 'c'];
  var xform = new ValueTransform<int, String>(
      (i) => letters[i], 
      (s) => letters.indexOf(s));  
  expect(xform.hasInverse, isTrue);
  expect(xform(2), equals('c'));
  expect(xform.inverse('b'), equals(1));
  expect(xform.inverse(xform(0)), equals(0));
}

@Test()
@ExpectError(isAssertionError)
void testTransformNoInverseThrows() {
  var xform = new ValueTransform<int, bool>((i) => i >= 1);
  xform.inverse(false);
}

// -----------------------------------------------------------------------------
// Custom
// -----------------------------------------------------------------------------

@Test('Test the registration of a custom string to int transform.')
void testRegisterCustomTransformStringToInt() {
  valueTransforms.add(const ValueTransform<String, int>(_string2int));
  expect(ValueTransform.canTransform(String, int), isTrue);
}

@Test('Test the registration of a custom rectangle transform.')
void testRegisterRectangleTransform() {
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isFalse);
  final transform = const ValueTransform<Rectangle, RectangleF>(_r2rf);
  valueTransforms.add(transform);
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isTrue);
  expect(valueTransforms.remove(transform), isTrue);
  expect(ValueTransform.canTransform(Rectangle, RectangleF), isFalse);
}

@Test('Test a valid rectangle transform.')
void testTransformRectangle() {  
  final transform = const ValueTransform<Rectangle, RectangleF>(_r2rf);
  valueTransforms.add(transform);  
  final r = new Rectangle()..x = 1..y = 2..w = 3..h = 4;
  final rf = ValueTransform.transform(r, Rectangle, RectangleF);
  expect(rf, const isInstanceOf<RectangleF>());
  expect(rf.x, equals(1));
  expect(rf.y, equals(2));
  expect(rf.w, equals(3));
  expect(rf.h, equals(4));
  expect(valueTransforms.remove(transform), isTrue);
}
